@@ -1,5 +1,51 @@
 var NAVTREEINDEX12 =
 {
+"structecs__world__info__t.html#a402efe5be309f8c0aa544f5e1b4f3caf":[17,0,0,1,3,1,29],
+"structecs__world__info__t.html#a4064930117e1990faf03594094545ee6":[17,0,0,1,3,1,13],
+"structecs__world__info__t.html#a40cbca3ca9140b44cb0f8f15b648bb54":[17,0,0,1,3,1,36],
+"structecs__world__info__t.html#a423da320e10ad87b102a25bd74368ed0":[17,0,0,1,3,1,8],
+"structecs__world__info__t.html#a476cbcb4156a37a512dcc76c6eed97c0":[17,0,0,1,3,1,16],
+"structecs__world__info__t.html#a69a67fda146fcd79f23232f07a32f443":[17,0,0,1,3,1,37],
+"structecs__world__info__t.html#a6b293969d1ea425bd7a4347ba5b4bcdc":[17,0,0,1,3,1,26],
+"structecs__world__info__t.html#a709766143fc7b96eeb173581ab535115":[17,0,0,1,3,1,34],
+"structecs__world__info__t.html#a7137546174c7ecb2ab211d2bbeedb07b":[17,0,0,1,3,1,18],
+"structecs__world__info__t.html#a74abc83acdc8b3dab7cde29f40bb354b":[17,0,0,1,3,1,35],
+"structecs__world__info__t.html#a7d5bf7bb6257b5e25c415e9982f116cf":[17,0,0,1,3,1,22],
+"structecs__world__info__t.html#a7eea83ed30b4d2fc45b215c55fdea065":[17,0,0,1,3,1,4],
+"structecs__world__info__t.html#a8903bd78dec7d3e3587449550ce78757":[17,0,0,1,3,1,9],
+"structecs__world__info__t.html#a95a15d721f0097f4138905745d57b479":[17,0,0,1,3,1,3],
+"structecs__world__info__t.html#a9602a1615e0a6f2c7c9ecc815026cdbe":[17,0,0,1,3,1,19],
+"structecs__world__info__t.html#a96932bc58af61e454e2b3adaf86bb1b9":[17,0,0,1,3,1,11],
+"structecs__world__info__t.html#aa4c02d4fe25be5db38562857bdd989c0":[17,0,0,1,3,1,15],
+"structecs__world__info__t.html#aa6ad73c201fbb7e95b242a7e47ce5455":[17,0,0,1,3,1,20],
+"structecs__world__info__t.html#aa9a9268a94b6a8c5f337b309f60e44b4":[17,0,0,1,3,1,21],
+"structecs__world__info__t.html#aab783a62bb921e69029de256f3c67d96":[17,0,0,1,3,1,27],
+"structecs__world__info__t.html#aaef75ee066e7ac07d87e3981691a1914":[17,0,0,1,3,1,1],
+"structecs__world__info__t.html#ab3807b0f99e15a5b51f0fe005faef828":[17,0,0,1,3,1,38],
+"structecs__world__info__t.html#abda93bc5d7bb20903380851b79ac4ea2":[17,0,0,1,3,1,6],
+"structecs__world__info__t.html#abeff90c0e8f3aeab0e7239e58dae0edc":[17,0,0,1,3,1,30],
+"structecs__world__info__t.html#abff0b796f60b04b1c07125725f2da679":[17,0,0,1,3,1,17],
+"structecs__world__info__t.html#ac5f59a01986840e4f50f3da781ad972e":[17,0,0,1,3,1,2],
+"structecs__world__info__t.html#ac88b4bbcfb1c4101531265844f1efaea":[17,0,0,1,3,1,41],
+"structecs__world__info__t.html#acd8c02366b31f72d77b26e8c6c971aa0":[17,0,0,1,3,1,28],
+"structecs__world__info__t.html#ad00bc59ae9524dab4b717254cb122063":[17,0,0,1,3,1,31],
+"structecs__world__info__t.html#ad020d3b27b217d172c0c64c7e4e3f1d9":[17,0,0,1,3,1,12],
+"structecs__world__info__t.html#ad059d897fe88116cb0450903d0bd7867":[17,0,0,1,3,1,40],
+"structecs__world__info__t.html#ad8e510cda71b25a716b2230b9b534f83":[17,0,0,1,3,1,43],
+"structecs__world__info__t.html#addc95155d813cdbe161453deb8404439":[17,0,0,1,3,1,10],
+"structecs__world__info__t.html#aedfc548cb8fc79b8754e6814a3c22bae":[17,0,0,1,3,1,24],
+"structecs__world__info__t.html#af13ccc527262482ab8b3c9edb64d8431":[17,0,0,1,3,1,25],
+"structecs__world__info__t.html#afd1bb68fe49013ad76047e64592f8100":[17,0,0,1,3,1,14],
+"structecs__world__info__t.html#afe0e60a00cc6a86fd9a43a939682401c":[17,0,0,1,3,1,0],
+"structecs__world__info__t.html#affad76fae2aaf5e94d51fc41b73e80f1":[17,0,0,1,3,1,32],
+"structecs__world__stats__t.html":[17,0,1,13,3],
+"structecs__world__stats__t.html#a0edb55575d5ff662074eea6ab2ef9cdf":[17,0,1,13,3,0],
+"structecs__world__stats__t.html#a11c0e5158e8d5867630ef94f3c5a5446":[17,0,1,13,3,2],
+"structecs__world__stats__t.html#a15ea5511a3641e79ba03c2c20dfbac12":[17,0,1,13,3,32],
+"structecs__world__stats__t.html#a160bac13f1ac5b8b2070fb503631a067":[17,0,1,13,3,38],
+"structecs__world__stats__t.html#a1bdd27808a598f06f9d505e7c124a32f":[17,0,1,13,3,7],
+"structecs__world__stats__t.html#a24a8c3539869b2e87594bd3f9fc74077":[17,0,1,13,3,26],
+"structecs__world__stats__t.html#a2954f7bc494267f0e9606bf69cd5e049":[17,0,1,13,3,14],
 "structecs__world__stats__t.html#a2eb49995c8cd6b5956229b5ae09a071c":[17,0,1,13,3,35],
 "structecs__world__stats__t.html#a381bed45fae8d3c4d4e522dad9ce6672":[17,0,1,13,3,4],
 "structecs__world__stats__t.html#a3b323258878f5bd95b992576017c614f":[17,0,1,13,3,31],
@@ -35,71 +81,136 @@ var NAVTREEINDEX12 =
 "structecs__world__to__json__desc__t.html":[17,0,1,4,3],
 "structecs__world__to__json__desc__t.html#a4d834cb3cc8a07e6939444a78d7c3fb1":[17,0,1,4,3,0],
 "structecs__world__to__json__desc__t.html#a8d3081712fade2690787517411a49a20":[17,0,1,4,3,1],
+"structflecs_1_1___1_1always__false.html":[18,0,0,0,0],
 "structflecs_1_1___1_1always__false.html":[19,0,0,0,0],
+"structflecs_1_1___1_1arg__list.html":[18,0,0,0,1],
 "structflecs_1_1___1_1arg__list.html":[19,0,0,0,1],
+"structflecs_1_1___1_1builder.html":[18,0,0,0,2],
 "structflecs_1_1___1_1builder.html":[19,0,0,0,2],
+"structflecs_1_1___1_1component__binding__ctx.html":[18,0,0,0,3],
 "structflecs_1_1___1_1component__binding__ctx.html":[19,0,0,0,3],
+"structflecs_1_1___1_1delegate.html":[18,0,0,0,4],
 "structflecs_1_1___1_1delegate.html":[19,0,0,0,4],
+"structflecs_1_1___1_1each__column__base.html":[18,0,0,0,5],
 "structflecs_1_1___1_1each__column__base.html":[19,0,0,0,5],
+"structflecs_1_1___1_1each__delegate.html":[18,0,0,0,6],
 "structflecs_1_1___1_1each__delegate.html":[19,0,0,0,6],
+"structflecs_1_1___1_1each__field.html":[18,0,0,0,7],
 "structflecs_1_1___1_1each__field.html":[19,0,0,0,7],
+"structflecs_1_1___1_1each__field_3_01T_00_01if__t_3_01_9is__pointer_3_01T_01_4_1_1value_01_6_6_95a4149db0e1a38cf6e613c74cd34116f.html":[18,0,0,0,9],
 "structflecs_1_1___1_1each__field_3_01T_00_01if__t_3_01_9is__pointer_3_01T_01_4_1_1value_01_6_6_95a4149db0e1a38cf6e613c74cd34116f.html":[19,0,0,0,9],
+"structflecs_1_1___1_1each__field_3_01T_00_01if__t_3_01_9is__pointer_3_01T_01_4_1_1value_01_6_6_9c1d5ea5264c62ce25452c48e8a2273b3.html":[18,0,0,0,8],
 "structflecs_1_1___1_1each__field_3_01T_00_01if__t_3_01_9is__pointer_3_01T_01_4_1_1value_01_6_6_9c1d5ea5264c62ce25452c48e8a2273b3.html":[19,0,0,0,8],
+"structflecs_1_1___1_1each__field_3_01T_00_01if__t_3_01is__empty_3_01actual__type__t_3_01T_01_4_0eb3698c06ea56f30276e2bfc220272a9.html":[18,0,0,0,10],
 "structflecs_1_1___1_1each__field_3_01T_00_01if__t_3_01is__empty_3_01actual__type__t_3_01T_01_4_0eb3698c06ea56f30276e2bfc220272a9.html":[19,0,0,0,10],
+"structflecs_1_1___1_1each__field_3_01T_00_01if__t_3_01is__pointer_3_01T_01_4_1_1value_01_6_6_9is4994fcebd92e4b3aa76b9794a34d4c7e.html":[18,0,0,0,11],
 "structflecs_1_1___1_1each__field_3_01T_00_01if__t_3_01is__pointer_3_01T_01_4_1_1value_01_6_6_9is4994fcebd92e4b3aa76b9794a34d4c7e.html":[19,0,0,0,11],
+"structflecs_1_1___1_1each__ref__field.html":[18,0,0,0,12],
 "structflecs_1_1___1_1each__ref__field.html":[19,0,0,0,12],
+"structflecs_1_1___1_1entity__observer__delegate.html":[18,0,0,0,13],
 "structflecs_1_1___1_1entity__observer__delegate.html":[19,0,0,0,13],
+"structflecs_1_1___1_1entity__observer__factory.html":[18,0,0,0,14],
 "structflecs_1_1___1_1entity__observer__factory.html":[19,0,0,0,14],
+"structflecs_1_1___1_1entity__payload__observer__delegate.html":[18,0,0,0,15],
 "structflecs_1_1___1_1entity__payload__observer__delegate.html":[19,0,0,0,15],
+"structflecs_1_1___1_1entity__with__delegate.html":[18,0,0,0,16],
 "structflecs_1_1___1_1entity__with__delegate.html":[19,0,0,0,16],
+"structflecs_1_1___1_1entity__with__delegate_3_01Func_00_01if__t_3_01is__callable_3_01Func_01_4_1_1value_01_4_01_4.html":[18,0,0,0,17],
 "structflecs_1_1___1_1entity__with__delegate_3_01Func_00_01if__t_3_01is__callable_3_01Func_01_4_1_1value_01_4_01_4.html":[19,0,0,0,17],
+"structflecs_1_1___1_1entity__with__delegate__impl.html":[18,0,0,0,18],
 "structflecs_1_1___1_1entity__with__delegate__impl.html":[19,0,0,0,18],
+"structflecs_1_1___1_1entity__with__delegate__impl_3_01arg__list_3_01Args_01_8_8_8_01_4_01_4.html":[18,0,0,0,19],
 "structflecs_1_1___1_1entity__with__delegate__impl_3_01arg__list_3_01Args_01_8_8_8_01_4_01_4.html":[19,0,0,0,19],
+"structflecs_1_1___1_1enum__constant__data.html":[18,0,0,0,20],
 "structflecs_1_1___1_1enum__constant__data.html":[19,0,0,0,20],
+"structflecs_1_1___1_1enum__data__impl.html":[18,0,0,0,21],
 "structflecs_1_1___1_1enum__data__impl.html":[19,0,0,0,21],
+"structflecs_1_1___1_1enum__is__valid.html":[18,0,0,0,22],
 "structflecs_1_1___1_1enum__is__valid.html":[19,0,0,0,22],
+"structflecs_1_1___1_1enum__reflection.html":[18,0,0,0,23],
 "structflecs_1_1___1_1enum__reflection.html":[19,0,0,0,23],
+"structflecs_1_1___1_1enum__type.html":[18,0,0,0,24],
 "structflecs_1_1___1_1enum__type.html":[19,0,0,0,24],
+"structflecs_1_1___1_1event__from__func.html":[18,0,0,0,25],
 "structflecs_1_1___1_1event__from__func.html":[19,0,0,0,25],
+"structflecs_1_1___1_1event__from__func_3_01Func_00_01if__t_3_01arity_3_01Func_01_4_1_1value_0a_0a1_01_4_01_4.html":[18,0,0,0,26],
 "structflecs_1_1___1_1event__from__func_3_01Func_00_01if__t_3_01arity_3_01Func_01_4_1_1value_0a_0a1_01_4_01_4.html":[19,0,0,0,26],
+"structflecs_1_1___1_1event__from__func_3_01Func_00_01if__t_3_01arity_3_01Func_01_4_1_1value_0a_0a2_01_4_01_4.html":[18,0,0,0,27],
 "structflecs_1_1___1_1event__from__func_3_01Func_00_01if__t_3_01arity_3_01Func_01_4_1_1value_0a_0a2_01_4_01_4.html":[19,0,0,0,27],
+"structflecs_1_1___1_1field__ptr.html":[18,0,0,0,28],
 "structflecs_1_1___1_1field__ptr.html":[19,0,0,0,28],
+"structflecs_1_1___1_1field__ptrs.html":[18,0,0,0,29],
 "structflecs_1_1___1_1field__ptrs.html":[19,0,0,0,29],
+"structflecs_1_1___1_1find__delegate.html":[18,0,0,0,30],
 "structflecs_1_1___1_1find__delegate.html":[19,0,0,0,30],
+"structflecs_1_1___1_1function__traits.html":[18,0,0,0,31],
 "structflecs_1_1___1_1function__traits.html":[19,0,0,0,31],
+"structflecs_1_1___1_1function__traits__defs.html":[18,0,0,0,32],
 "structflecs_1_1___1_1function__traits__defs.html":[19,0,0,0,32],
+"structflecs_1_1___1_1function__traits__impl.html":[18,0,0,0,33],
 "structflecs_1_1___1_1function__traits__impl.html":[19,0,0,0,33],
+"structflecs_1_1___1_1function__traits__impl_3_01ReturnType_07Args_8_8_8_08_4.html":[18,0,0,0,35],
 "structflecs_1_1___1_1function__traits__impl_3_01ReturnType_07Args_8_8_8_08_4.html":[19,0,0,0,35],
+"structflecs_1_1___1_1function__traits__impl_3_01ReturnType_07ClassType_1_1_5_08_07Args_8_8_8_08_01const_01_4.html":[18,0,0,0,38],
 "structflecs_1_1___1_1function__traits__impl_3_01ReturnType_07ClassType_1_1_5_08_07Args_8_8_8_08_01const_01_4.html":[19,0,0,0,38],
+"structflecs_1_1___1_1function__traits__impl_3_01ReturnType_07ClassType_1_1_5_08_07Args_8_8_8_08_01const_01_6_01_4.html":[18,0,0,0,36],
 "structflecs_1_1___1_1function__traits__impl_3_01ReturnType_07ClassType_1_1_5_08_07Args_8_8_8_08_01const_01_6_01_4.html":[19,0,0,0,36],
+"structflecs_1_1___1_1function__traits__impl_3_01ReturnType_07ClassType_1_1_5_08_07Args_8_8_8_08_01const_01_6_6_01_4.html":[18,0,0,0,37],
 "structflecs_1_1___1_1function__traits__impl_3_01ReturnType_07ClassType_1_1_5_08_07Args_8_8_8_08_01const_01_6_6_01_4.html":[19,0,0,0,37],
+"structflecs_1_1___1_1function__traits__impl_3_01ReturnType_07ClassType_1_1_5_08_07Args_8_8_8_08_01const_01volatile_01_4.html":[18,0,0,0,41],
 "structflecs_1_1___1_1function__traits__impl_3_01ReturnType_07ClassType_1_1_5_08_07Args_8_8_8_08_01const_01volatile_01_4.html":[19,0,0,0,41],
+"structflecs_1_1___1_1function__traits__impl_3_01ReturnType_07ClassType_1_1_5_08_07Args_8_8_8_08_01const_01volatile_01_6_01_4.html":[18,0,0,0,39],
 "structflecs_1_1___1_1function__traits__impl_3_01ReturnType_07ClassType_1_1_5_08_07Args_8_8_8_08_01const_01volatile_01_6_01_4.html":[19,0,0,0,39],
+"structflecs_1_1___1_1function__traits__impl_3_01ReturnType_07ClassType_1_1_5_08_07Args_8_8_8_08_01const_01volatile_01_6_6_01_4.html":[18,0,0,0,40],
 "structflecs_1_1___1_1function__traits__impl_3_01ReturnType_07ClassType_1_1_5_08_07Args_8_8_8_08_01const_01volatile_01_6_6_01_4.html":[19,0,0,0,40],
+"structflecs_1_1___1_1function__traits__impl_3_01ReturnType_07ClassType_1_1_5_08_07Args_8_8_8_08_01volatile_01_4.html":[18,0,0,0,44],
 "structflecs_1_1___1_1function__traits__impl_3_01ReturnType_07ClassType_1_1_5_08_07Args_8_8_8_08_01volatile_01_4.html":[19,0,0,0,44],
+"structflecs_1_1___1_1function__traits__impl_3_01ReturnType_07ClassType_1_1_5_08_07Args_8_8_8_08_01volatile_01_6_01_4.html":[18,0,0,0,42],
 "structflecs_1_1___1_1function__traits__impl_3_01ReturnType_07ClassType_1_1_5_08_07Args_8_8_8_08_01volatile_01_6_01_4.html":[19,0,0,0,42],
+"structflecs_1_1___1_1function__traits__impl_3_01ReturnType_07ClassType_1_1_5_08_07Args_8_8_8_08_01volatile_01_6_6_01_4.html":[18,0,0,0,43],
 "structflecs_1_1___1_1function__traits__impl_3_01ReturnType_07ClassType_1_1_5_08_07Args_8_8_8_08_01volatile_01_6_6_01_4.html":[19,0,0,0,43],
+"structflecs_1_1___1_1function__traits__impl_3_01ReturnType_07ClassType_1_1_5_08_07Args_8_8_8_08_4.html":[18,0,0,0,45],
 "structflecs_1_1___1_1function__traits__impl_3_01ReturnType_07ClassType_1_1_5_08_07Args_8_8_8_08_4.html":[19,0,0,0,45],
+"structflecs_1_1___1_1function__traits__impl_3_01ReturnType_07_5_08_07Args_8_8_8_08_4.html":[18,0,0,0,34],
 "structflecs_1_1___1_1function__traits__impl_3_01ReturnType_07_5_08_07Args_8_8_8_08_4.html":[19,0,0,0,34],
+"structflecs_1_1___1_1function__traits__no__cv.html":[18,0,0,0,46],
 "structflecs_1_1___1_1function__traits__no__cv.html":[19,0,0,0,46],
+"structflecs_1_1___1_1function__traits__no__cv_3_01T_00_01decltype_07_07void_08_6T_1_1operator_07_08_08_4.html":[18,0,0,0,47],
 "structflecs_1_1___1_1function__traits__no__cv_3_01T_00_01decltype_07_07void_08_6T_1_1operator_07_08_08_4.html":[19,0,0,0,47],
+"structflecs_1_1___1_1node__builder.html":[18,0,0,0,48],
 "structflecs_1_1___1_1node__builder.html":[19,0,0,0,48],
 "structflecs_1_1___1_1pair__base.html":[17,1,0,8,0],
+"structflecs_1_1___1_1placement__new__tag__t.html":[18,0,0,0,50],
 "structflecs_1_1___1_1placement__new__tag__t.html":[19,0,0,0,50],
+"structflecs_1_1___1_1query__delegate.html":[18,0,0,0,51],
 "structflecs_1_1___1_1query__delegate.html":[19,0,0,0,51],
+"structflecs_1_1___1_1query__delegate_3_01Func_00_01if__not__t_3_01is__same_3_01first__arg__t_3_0680960bf4a5f486c0c0082c925e33592.html":[18,0,0,0,52],
 "structflecs_1_1___1_1query__delegate_3_01Func_00_01if__not__t_3_01is__same_3_01first__arg__t_3_0680960bf4a5f486c0c0082c925e33592.html":[19,0,0,0,52],
+"structflecs_1_1___1_1query__delegate_3_01Func_00_01if__t_3_01is__same_3_01first__arg__t_3_01Func037581d416b58c8c188fb392038e4ec9.html":[18,0,0,0,53],
 "structflecs_1_1___1_1query__delegate_3_01Func_00_01if__t_3_01is__same_3_01first__arg__t_3_01Func037581d416b58c8c188fb392038e4ec9.html":[19,0,0,0,53],
+"structflecs_1_1___1_1query__delegate__no__ent.html":[18,0,0,0,54],
 "structflecs_1_1___1_1query__delegate__no__ent.html":[19,0,0,0,54],
+"structflecs_1_1___1_1query__delegate__no__ent_3_01Func_00_01arg__list_3_01Args_01_8_8_8_01_4_01_4.html":[18,0,0,0,55],
 "structflecs_1_1___1_1query__delegate__no__ent_3_01Func_00_01arg__list_3_01Args_01_8_8_8_01_4_01_4.html":[19,0,0,0,55],
+"structflecs_1_1___1_1query__delegate__w__ent.html":[18,0,0,0,56],
 "structflecs_1_1___1_1query__delegate__w__ent.html":[19,0,0,0,56],
+"structflecs_1_1___1_1query__delegate__w__ent_3_01Func_00_01arg__list_3_01E_00_01Args_01_8_8_8_01_4_01_4.html":[18,0,0,0,57],
 "structflecs_1_1___1_1query__delegate__w__ent_3_01Func_00_01arg__list_3_01E_00_01Args_01_8_8_8_01_4_01_4.html":[19,0,0,0,57],
+"structflecs_1_1___1_1range__iterator.html":[18,0,0,0,58],
 "structflecs_1_1___1_1range__iterator.html":[19,0,0,0,58],
+"structflecs_1_1___1_1run__delegate.html":[18,0,0,0,59],
 "structflecs_1_1___1_1run__delegate.html":[19,0,0,0,59],
+"structflecs_1_1___1_1sig.html":[18,0,0,0,60],
 "structflecs_1_1___1_1sig.html":[19,0,0,0,60],
+"structflecs_1_1___1_1to__constant.html":[18,0,0,0,61],
 "structflecs_1_1___1_1to__constant.html":[19,0,0,0,61],
+"structflecs_1_1___1_1type.html":[18,0,0,0,62],
 "structflecs_1_1___1_1type.html":[19,0,0,0,62],
+"structflecs_1_1___1_1type_3_01T_00_01if__not__t_3_01is__pair_3_01T_01_4_1_1value_01_4_01_4.html":[18,0,0,0,63],
 "structflecs_1_1___1_1type_3_01T_00_01if__not__t_3_01is__pair_3_01T_01_4_1_1value_01_4_01_4.html":[19,0,0,0,63],
+"structflecs_1_1___1_1type_3_01T_00_01if__t_3_01is__pair_3_01T_01_4_1_1value_01_4_01_4.html":[18,0,0,0,64],
 "structflecs_1_1___1_1type_3_01T_00_01if__t_3_01is__pair_3_01T_01_4_1_1value_01_4_01_4.html":[19,0,0,0,64],
+"structflecs_1_1___1_1type__impl.html":[18,0,0,0,65],
 "structflecs_1_1___1_1type__impl.html":[19,0,0,0,65],
 "structflecs_1_1actual__type.html":[17,1,0,8,3],
 "structflecs_1_1actual__type_3_01T_00_01if__not__t_3_01is__pair_3_01T_01_4_1_1value_01_4_01_4.html":[17,1,0,8,4],
@@ -130,124 +241,13 @@ var NAVTREEINDEX12 =
 "structflecs_1_1alerts_1_1Info.html":[17,1,1,1,2,2],
 "structflecs_1_1alerts_1_1Warning.html":[17,1,1,1,2,3],
 "structflecs_1_1app__builder.html":[17,1,1,2,0],
+"structflecs_1_1arity.html":[18,0,0,9],
 "structflecs_1_1arity.html":[19,0,0,9],
+"structflecs_1_1array.html":[18,0,0,10],
 "structflecs_1_1array.html":[19,0,0,10],
+"structflecs_1_1array_3_01T_00_01Size_00_01enable__if__t_3_01Size_01_9_0a0_01_4_01_4.html":[18,0,0,11],
 "structflecs_1_1array_3_01T_00_01Size_00_01enable__if__t_3_01Size_01_9_0a0_01_4_01_4.html":[19,0,0,11],
+"structflecs_1_1array_3_01T_00_01Size_00_01enable__if__t_3_01Size_0a_0a0_01_4_01_4.html":[18,0,0,12],
 "structflecs_1_1array_3_01T_00_01Size_00_01enable__if__t_3_01Size_0a_0a0_01_4_01_4.html":[19,0,0,12],
-"structflecs_1_1array__iterator.html":[19,0,0,13],
-"structflecs_1_1base__arg__type.html":[17,1,0,8,7],
-"structflecs_1_1base__type.html":[17,1,0,8,6],
-"structflecs_1_1bitmask.html":[17,1,1,6,1],
-"structflecs_1_1component.html":[17,1,0,1,1],
-"structflecs_1_1component.html#a2e628547c417f615e25344bb66aff669":[17,1,0,1,1,3],
-"structflecs_1_1component.html#a354267ca96c1c6ab7c75b42633e1541d":[17,1,0,1,1,0],
-"structflecs_1_1component.html#a703595217b5e45e17f053aeade60da3c":[17,1,0,1,1,2],
-"structflecs_1_1component.html#a9c6489382d8c6b7fe9d2be810852f9f7":[17,1,0,1,1,4],
-"structflecs_1_1cursor.html":[17,1,1,6,0],
-"structflecs_1_1cursor.html#a03eed702d36c639e45477c8ae4e697ba":[17,1,1,6,0,9],
-"structflecs_1_1cursor.html#a084ec64540024ed9b60b8116e10ba72f":[17,1,1,6,0,17],
-"structflecs_1_1cursor.html#a0e27c444045e7c3effa19851ee71485d":[17,1,1,6,0,25],
-"structflecs_1_1cursor.html#a1c36f16b6f7f43b968ff31d14da4209e":[17,1,1,6,0,8],
-"structflecs_1_1cursor.html#a2022825bb666cacedc52bb660605227b":[17,1,1,6,0,22],
-"structflecs_1_1cursor.html#a20ea24c16f3d3f18378ea844e4332546":[17,1,1,6,0,13],
-"structflecs_1_1cursor.html#a2af9896c6fc8a2ddc75c2a05d7ff7ab7":[17,1,1,6,0,10],
-"structflecs_1_1cursor.html#a33ce716229765d7f115996c4aa71981b":[17,1,1,6,0,2],
-"structflecs_1_1cursor.html#a3810df4e364b65df3a8e36c96f198efe":[17,1,1,6,0,0],
-"structflecs_1_1cursor.html#a3adc17280eb790947e64eed6de4909fd":[17,1,1,6,0,1],
-"structflecs_1_1cursor.html#a3e53d2afaa37fb8e044482a2384047ab":[17,1,1,6,0,20],
-"structflecs_1_1cursor.html#a528e6886b587429b4baf8fe96b9bb520":[17,1,1,6,0,4],
-"structflecs_1_1cursor.html#a6fc3bbd332bffd3539dfe130049cfe71":[17,1,1,6,0,18],
-"structflecs_1_1cursor.html#a77fcd07e916fed2d662528853e30327c":[17,1,1,6,0,6],
-"structflecs_1_1cursor.html#a7f86b21ea560535153df329916b63875":[17,1,1,6,0,23],
-"structflecs_1_1cursor.html#a82987012e0ed683bd950cdfb85be8b2e":[17,1,1,6,0,12],
-"structflecs_1_1cursor.html#a8f3c89c8e8bfe7576afc0e01677e2bde":[17,1,1,6,0,16],
-"structflecs_1_1cursor.html#a92733888ebc19677a17dcaf20d420913":[17,1,1,6,0,21],
-"structflecs_1_1cursor.html#a9479ca654a08eefeffa65223e463b9b1":[17,1,1,6,0,26],
-"structflecs_1_1cursor.html#a9f2c35183cf70cad79cdbe66538d86d4":[17,1,1,6,0,24],
-"structflecs_1_1cursor.html#aa578e355ec10642e448f8734d1588c07":[17,1,1,6,0,15],
-"structflecs_1_1cursor.html#aa665965fc53a4eb3993979e3112964e4":[17,1,1,6,0,5],
-"structflecs_1_1cursor.html#ab553e70a9c40587d08a8ba90bfa674d6":[17,1,1,6,0,3],
-"structflecs_1_1cursor.html#ab8794043381406ddc8c980c74eb0b60e":[17,1,1,6,0,19],
-"structflecs_1_1cursor.html#ad4101a572b0d62021d9b315066d7121a":[17,1,1,6,0,14],
-"structflecs_1_1cursor.html#ad78cae14d4ff6ce2415acfb8cae4d02d":[17,1,1,6,0,11],
-"structflecs_1_1cursor.html#ae1449fabc9c72ba0b94a90916fde3eb5":[17,1,1,6,0,7],
-"structflecs_1_1cursor.html#af1b4e5e6559bde05da114fe7ea470dfe":[17,1,1,6,0,27],
-"structflecs_1_1entity.html":[17,1,0,2,0],
-"structflecs_1_1entity.html#a05c1af95015764fc68aa790d274f4462":[17,1,0,2,0,5],
-"structflecs_1_1entity.html#a0cedfc7447654b086c0e6a9d6086515f":[17,1,0,2,0,13],
-"structflecs_1_1entity.html#a0e494b2a380e94acb8a15e10eb031170":[17,1,0,2,0,19],
-"structflecs_1_1entity.html#a32ec3d1b9da53261fc3981c1f7e2277b":[17,1,0,2,0,10],
-"structflecs_1_1entity.html#a34ed2767da35c164134b21f4d4a083b4":[17,1,0,2,0,17],
-"structflecs_1_1entity.html#a3a115a6cbd08c6de08e0ecfe8608ccbb":[17,1,0,2,0,4],
-"structflecs_1_1entity.html#a46b645e7cdfe073077b392231e231f10":[17,1,0,2,0,18],
-"structflecs_1_1entity.html#a5507fae8c3f326e957f468372b63b322":[17,1,0,2,0,2],
-"structflecs_1_1entity.html#a6489d776974b5cd87b5e84f557b16a79":[17,1,0,2,0,9],
-"structflecs_1_1entity.html#a88d980f044b22194dfed0c9a7d9582c7":[17,1,0,2,0,16],
-"structflecs_1_1entity.html#a8baaadf7cffb365c70109d5b00e54fea":[17,1,0,2,0,1],
-"structflecs_1_1entity.html#a8cb796e5781775753b5ca8fd9d85b59e":[17,1,0,2,0,15],
-"structflecs_1_1entity.html#a8fca9021f1846e165eba581adaee64ba":[17,1,0,2,0,6],
-"structflecs_1_1entity.html#a969ca3768656ad39ac63fced5ccadf91":[17,1,0,2,0,11],
-"structflecs_1_1entity.html#a9c49f2a9835015eaa9836c3d5d8e286e":[17,1,0,2,0,8],
-"structflecs_1_1entity.html#a9d2361efe2ea358b3bd0728408ced507":[17,1,0,2,0,3],
-"structflecs_1_1entity.html#ac475621a5fb9513885c12474ba7ffd67":[17,1,0,2,0,0],
-"structflecs_1_1entity.html#acc0abe24401b9c3fb54187258a7edb64":[17,1,0,2,0,20],
-"structflecs_1_1entity.html#aee5caacc56de16ca8198f4bafb6bc90c":[17,1,0,2,0,14],
-"structflecs_1_1entity.html#af332067cf1fc966681c74f93dbfd3ba0":[17,1,0,2,0,7],
-"structflecs_1_1entity__builder.html":[17,1,0,2,2],
-"structflecs_1_1entity__builder.html#a02b34720fff76a1b9ff672aa962dcef2":[17,1,0,2,2,32],
-"structflecs_1_1entity__builder.html#a04cf84a7131b162ba2b84ecaa552fb84":[17,1,0,2,2,24],
-"structflecs_1_1entity__builder.html#a0d5b19b619f9d78bf53f9ed74b180173":[17,1,0,2,2,39],
-"structflecs_1_1entity__builder.html#a0f4b5dfcb8e444373fe51623510ea8ca":[17,1,0,2,2,2],
-"structflecs_1_1entity__builder.html#a146289ece6a533e68b6a3a38d991099d":[17,1,0,2,2,59],
-"structflecs_1_1entity__builder.html#a153fb2651447dc3f4137b291a977f0eb":[17,1,0,2,2,17],
-"structflecs_1_1entity__builder.html#a17d5969d188b9f1c65f2e746fc05db6f":[17,1,0,2,2,38],
-"structflecs_1_1entity__builder.html#a191f9218a8fa5c2e9f235a91a4dc49a7":[17,1,0,2,2,52],
-"structflecs_1_1entity__builder.html#a19cc5f971f1a45a93f92cd812be554bb":[17,1,0,2,2,51],
-"structflecs_1_1entity__builder.html#a1c571dff751ee47f3c5a95a431ece77f":[17,1,0,2,2,9],
-"structflecs_1_1entity__builder.html#a1da22fbfb4d80e9b6291758d7a306f57":[17,1,0,2,2,53],
-"structflecs_1_1entity__builder.html#a1e51fec5a536bf1f800406bc6c2795ed":[17,1,0,2,2,30],
-"structflecs_1_1entity__builder.html#a20b11e2eb5c8b567e5e40b609c1fb4f2":[17,1,0,2,2,65],
-"structflecs_1_1entity__builder.html#a28ef5b21eb210f57bfef85462ac56b4d":[17,1,0,2,2,46],
-"structflecs_1_1entity__builder.html#a2ab0a844d5f4a0b1865578a2bf19af57":[17,1,0,2,2,27],
-"structflecs_1_1entity__builder.html#a2b975bffc8628a9603fd6f2774c9dc08":[17,1,0,2,2,31],
-"structflecs_1_1entity__builder.html#a378cf10142876b10354f3f3761676f4a":[17,1,0,2,2,1],
-"structflecs_1_1entity__builder.html#a3963c4b9c5441f46edfef951cfd44d55":[17,1,0,2,2,42],
-"structflecs_1_1entity__builder.html#a3bd3159a876072b275bf5ce3a071b95f":[17,1,0,2,2,33],
-"structflecs_1_1entity__builder.html#a404a701f159da50aa62c1104f8898423":[17,1,0,2,2,54],
-"structflecs_1_1entity__builder.html#a419cd6b824d5778c56140b424474821b":[17,1,0,2,2,83],
-"structflecs_1_1entity__builder.html#a45b772f4c004019272c35a5df3994106":[17,1,0,2,2,14],
-"structflecs_1_1entity__builder.html#a45e4f02f1e5a677132c4075a5c90f50d":[17,1,0,2,2,34],
-"structflecs_1_1entity__builder.html#a47a86bfaacdfba0fe44e7c5188a8d449":[17,1,0,2,2,55],
-"structflecs_1_1entity__builder.html#a4a8996a0d9c528294da5bc6f22873841":[17,1,0,2,2,40],
-"structflecs_1_1entity__builder.html#a4bc696009d7dee0408c2676df89db6b5":[17,1,0,2,2,19],
-"structflecs_1_1entity__builder.html#a5344856be84e6fe5a638a896050d4b93":[17,1,0,2,2,57],
-"structflecs_1_1entity__builder.html#a554515e6ae5dca1231c1627f0752512b":[17,1,0,2,2,62],
-"structflecs_1_1entity__builder.html#a5b8d20beb011c31f41de9627a19acb63":[17,1,0,2,2,35],
-"structflecs_1_1entity__builder.html#a5ccd8e62330f1a04f2a4942074d51912":[17,1,0,2,2,36],
-"structflecs_1_1entity__builder.html#a5d5576de6136754c371925634df684fa":[17,1,0,2,2,45],
-"structflecs_1_1entity__builder.html#a5e9b68ad145c42dbf820807010b42f15":[17,1,0,2,2,28],
-"structflecs_1_1entity__builder.html#a5ed232a47807a146194bcc2873d95100":[17,1,0,2,2,81],
-"structflecs_1_1entity__builder.html#a6dd543de232e2d9dcc7fab90c104f071":[17,1,0,2,2,60],
-"structflecs_1_1entity__builder.html#a706f6b2ffa0bd3d013b8f07506f92ec3":[17,1,0,2,2,8],
-"structflecs_1_1entity__builder.html#a77ae0fae5526a20b3187a30bb294dc82":[17,1,0,2,2,43],
-"structflecs_1_1entity__builder.html#a78a6ed2ee64e83a66576a89b5170532d":[17,1,0,2,2,5],
-"structflecs_1_1entity__builder.html#a79433c1ec01dd26b6e70ddf76b772585":[17,1,0,2,2,22],
-"structflecs_1_1entity__builder.html#a7ab5e4aef52e28b8bce9b194774e5b33":[17,1,0,2,2,10],
-"structflecs_1_1entity__builder.html#a81e94bad637236db20f21608ef7613ed":[17,1,0,2,2,80],
-"structflecs_1_1entity__builder.html#a8415fc06bc3afec03a12746b7c975c4b":[17,1,0,2,2,67],
-"structflecs_1_1entity__builder.html#a8599118f821b34753619d26a6dc13501":[17,1,0,2,2,7],
-"structflecs_1_1entity__builder.html#a8c9afcf9e1c26207f78f57430a48e1b5":[17,1,0,2,2,47],
-"structflecs_1_1entity__builder.html#a8c9afcf9e1c26207f78f57430a48e1b5":[17,1,0,2,2,48],
-"structflecs_1_1entity__builder.html#a8c9afcf9e1c26207f78f57430a48e1b5":[17,1,0,2,2,49],
-"structflecs_1_1entity__builder.html#a8def0956e65d1875a55e074d8c708dca":[17,1,0,2,2,25],
-"structflecs_1_1entity__builder.html#a8f5e829cc6cdd42395436e447c078d52":[17,1,0,2,2,4],
-"structflecs_1_1entity__builder.html#a97a83b4d51ceb0004a5793e208e906ac":[17,1,0,2,2,3],
-"structflecs_1_1entity__builder.html#a99409ffe8c3d12dc7adaf50c66569ff7":[17,1,0,2,2,86],
-"structflecs_1_1entity__builder.html#a99a05333374dba34c0aa2fe9843d366f":[17,1,0,2,2,61],
-"structflecs_1_1entity__builder.html#a9a498296757c345b11115079fd8914d7":[17,1,0,2,2,41],
-"structflecs_1_1entity__builder.html#a9a98eb882db1004e8ef0ea4d04191d21":[17,1,0,2,2,56],
-"structflecs_1_1entity__builder.html#a9d651da4c0157c71e8e9bddf766bc34c":[17,1,0,2,2,11],
-"structflecs_1_1entity__builder.html#a9fc35623fba54ecc3a5a73cddc7b58d7":[17,1,0,2,2,13],
-"structflecs_1_1entity__builder.html#a9ff2735c8ba886c032335be708315e96":[17,1,0,2,2,12],
-"structflecs_1_1entity__builder.html#aaaf9f331066ed419e5b564fe16791ef5":[17,1,0,2,2,85]
+"structflecs_1_1array__iterator.html":[18,0,0,13]
 };
