@@ -1,5 +1,42 @@
 var NAVTREEINDEX7 =
 {
+"md_docs_2EntitiesComponents.html":[4],
+"md_docs_2EntitiesComponents.html#clearing":[4,1,2],
+"md_docs_2EntitiesComponents.html#components-1":[4,2],
+"md_docs_2EntitiesComponents.html#components-are-entities":[4,2,1],
+"md_docs_2EntitiesComponents.html#creation":[4,1,0],
+"md_docs_2EntitiesComponents.html#deletion":[4,1,1],
+"md_docs_2EntitiesComponents.html#disabling":[4,1,8],
+"md_docs_2EntitiesComponents.html#disabling-1":[4,2,5],
+"md_docs_2EntitiesComponents.html#entities-1":[4,1],
+"md_docs_2EntitiesComponents.html#introduction":[4,0],
+"md_docs_2EntitiesComponents.html#liveliness-checking":[4,1,3],
+"md_docs_2EntitiesComponents.html#manual-ids":[4,1,4],
+"md_docs_2EntitiesComponents.html#manual-versioning":[4,1,5],
+"md_docs_2EntitiesComponents.html#names":[4,1,7],
+"md_docs_2EntitiesComponents.html#operations":[4,2,0],
+"md_docs_2EntitiesComponents.html#ranges":[4,1,6],
+"md_docs_2EntitiesComponents.html#registration":[4,2,2],
+"md_docs_2EntitiesComponents.html#runtime-type-registration":[4,2,2,0],
+"md_docs_2EntitiesComponents.html#singletons":[4,2,4],
+"md_docs_2EntitiesComponents.html#unregistration":[4,2,3],
+"md_docs_2FAQ.html":[1],
+"md_docs_2FAQ.html#are-relationships-just-a-component-with-an-entity-handle":[1,20],
+"md_docs_2FAQ.html#can-flecs-be-compiled-to-web-assembly":[1,10],
+"md_docs_2FAQ.html#can-flecs-serialize-components":[1,14],
+"md_docs_2FAQ.html#can-i-add-or-remove-components-from-within-a-system":[1,25],
+"md_docs_2FAQ.html#can-i-create-systems-outside-of-the-main-function":[1,21],
+"md_docs_2FAQ.html#can-i-use-flecs-with-c14-or-higher":[1,2],
+"md_docs_2FAQ.html#can-i-use-flecs-without-using-systems":[1,23],
+"md_docs_2FAQ.html#can-i-use-my-own-scheduler-implementation":[1,22],
+"md_docs_2FAQ.html#can-i-use-stdvector-or-other-types-inside-components":[1,3],
+"md_docs_2FAQ.html#does-the-explorer-collect-data-from-my-application":[1,17],
+"md_docs_2FAQ.html#how-do-i-detect-which-entities-have-changed":[1,19],
+"md_docs_2FAQ.html#how-does-flecs-compare-with-entt":[1,5],
+"md_docs_2FAQ.html#is-flecs-used-for-commercial-projects":[1,6],
+"md_docs_2FAQ.html#what-does-a-locked_storage-error-mean":[1,26],
+"md_docs_2FAQ.html#what-is-an-archetype":[1,4],
+"md_docs_2FAQ.html#what-is-an-ecs":[1,0],
 "md_docs_2FAQ.html#what-is-the-difference-between-add--set-why-do-both-exist":[1,13],
 "md_docs_2FAQ.html#why-am-i-getting-an-use-of-undeclared-identifier-flecs_id--compiler-error":[1,11],
 "md_docs_2FAQ.html#why-are-my-entity-ids-so-large":[1,12],
@@ -12,16 +49,17 @@ var NAVTREEINDEX7 =
 "md_docs_2FAQ.html#why-is-flecs-written-in-c":[1,1],
 "md_docs_2FAQ.html#why-is-my-system-called-multiple-times-per-frame":[1,9],
 "md_docs_2FlecsQueryLanguage.html":[6],
-"md_docs_2FlecsQueryLanguage.html#advanced":[6,8],
+"md_docs_2FlecsQueryLanguage.html#access-modifiers-1":[6,4],
+"md_docs_2FlecsQueryLanguage.html#advanced":[6,9],
 "md_docs_2FlecsQueryLanguage.html#andfrom":[6,3,3],
-"md_docs_2FlecsQueryLanguage.html#any-wildcard-_":[6,4,1],
+"md_docs_2FlecsQueryLanguage.html#any-wildcard-_":[6,5,1],
 "md_docs_2FlecsQueryLanguage.html#components-3":[6,2,0],
-"md_docs_2FlecsQueryLanguage.html#dependent-variables":[6,8,3],
-"md_docs_2FlecsQueryLanguage.html#equality-operators-1":[6,8,0],
+"md_docs_2FlecsQueryLanguage.html#dependent-variables":[6,9,3],
+"md_docs_2FlecsQueryLanguage.html#equality-operators-1":[6,9,0],
 "md_docs_2FlecsQueryLanguage.html#example":[6,1],
 "md_docs_2FlecsQueryLanguage.html#introduction-2":[6,0],
-"md_docs_2FlecsQueryLanguage.html#lookup-variables-1":[6,8,1],
-"md_docs_2FlecsQueryLanguage.html#member-matching":[6,8,2],
+"md_docs_2FlecsQueryLanguage.html#lookup-variables-1":[6,9,1],
+"md_docs_2FlecsQueryLanguage.html#member-matching":[6,9,2],
 "md_docs_2FlecsQueryLanguage.html#not":[6,3,0],
 "md_docs_2FlecsQueryLanguage.html#notfrom":[6,3,4],
 "md_docs_2FlecsQueryLanguage.html#operators":[6,3],
@@ -29,16 +67,16 @@ var NAVTREEINDEX7 =
 "md_docs_2FlecsQueryLanguage.html#or":[6,3,1],
 "md_docs_2FlecsQueryLanguage.html#orfrom":[6,3,5],
 "md_docs_2FlecsQueryLanguage.html#pairs-1":[6,2,1],
-"md_docs_2FlecsQueryLanguage.html#query-scopes-1":[6,8,4],
-"md_docs_2FlecsQueryLanguage.html#singleton-source":[6,6,1],
-"md_docs_2FlecsQueryLanguage.html#source-1":[6,6],
-"md_docs_2FlecsQueryLanguage.html#static-source":[6,6,0],
+"md_docs_2FlecsQueryLanguage.html#query-scopes-1":[6,9,4],
+"md_docs_2FlecsQueryLanguage.html#singleton-source":[6,7,1],
+"md_docs_2FlecsQueryLanguage.html#source-1":[6,7],
+"md_docs_2FlecsQueryLanguage.html#static-source":[6,7,0],
 "md_docs_2FlecsQueryLanguage.html#the-basics":[6,2],
-"md_docs_2FlecsQueryLanguage.html#traversal":[6,7],
-"md_docs_2FlecsQueryLanguage.html#variable-source":[6,6,2],
-"md_docs_2FlecsQueryLanguage.html#variables-1":[6,5],
-"md_docs_2FlecsQueryLanguage.html#wildcard-wildcard-":[6,4,0],
-"md_docs_2FlecsQueryLanguage.html#wildcards-1":[6,4],
+"md_docs_2FlecsQueryLanguage.html#traversal":[6,8],
+"md_docs_2FlecsQueryLanguage.html#variable-source":[6,7,2],
+"md_docs_2FlecsQueryLanguage.html#variables-1":[6,6],
+"md_docs_2FlecsQueryLanguage.html#wildcard-wildcard-":[6,5,0],
+"md_docs_2FlecsQueryLanguage.html#wildcards-1":[6,5],
 "md_docs_2FlecsRemoteApi.html":[14],
 "md_docs_2FlecsRemoteApi.html#delete-component":[14,3,5],
 "md_docs_2FlecsRemoteApi.html#delete-entity":[14,3,2],
@@ -211,43 +249,5 @@ var NAVTREEINDEX7 =
 "md_docs_2Queries.html#member-value-queries":[5,6,16],
 "md_docs_2Queries.html#none":[5,3,2,3],
 "md_docs_2Queries.html#not-operator":[5,6,7],
-"md_docs_2Queries.html#operator-overview":[5,6,4],
-"md_docs_2Queries.html#optional-operator":[5,6,8],
-"md_docs_2Queries.html#or-operator":[5,6,6],
-"md_docs_2Queries.html#pairs":[5,6,2],
-"md_docs_2Queries.html#performance-and-caching":[5,3],
-"md_docs_2Queries.html#performance-tips--tricks":[5,3,3],
-"md_docs_2Queries.html#query-scopes":[5,6,11],
-"md_docs_2Queries.html#reference":[5,6],
-"md_docs_2Queries.html#reflexive-relationships":[5,6,22],
-"md_docs_2Queries.html#relationship-traversal":[5,6,14],
-"md_docs_2Queries.html#rematching":[5,3,3,0],
-"md_docs_2Queries.html#setting-variables":[5,6,15,0],
-"md_docs_2Queries.html#singletons-1":[5,6,13],
-"md_docs_2Queries.html#sorting":[5,6,18],
-"md_docs_2Queries.html#sorting-algorithm":[5,6,18,0],
-"md_docs_2Queries.html#source":[5,6,12],
-"md_docs_2Queries.html#tradeoffs":[5,3,1],
-"md_docs_2Queries.html#transitive-relationships":[5,6,21],
-"md_docs_2Queries.html#traversal-flags":[5,6,14,0],
-"md_docs_2Queries.html#variables":[5,6,15],
-"md_docs_2Queries.html#wildcards":[5,6,1],
-"md_docs_2Quickstart.html":[2],
-"md_docs_2Quickstart.html#addons":[2,0,5],
-"md_docs_2Quickstart.html#building-flecs":[2,0],
-"md_docs_2Quickstart.html#building-with-bake":[2,0,2],
-"md_docs_2Quickstart.html#building-with-cmake":[2,0,1],
-"md_docs_2Quickstart.html#component":[2,1,3],
-"md_docs_2Quickstart.html#concepts":[2,1],
-"md_docs_2Quickstart.html#dynamic-linking":[2,0,0],
-"md_docs_2Quickstart.html#emscripten":[2,0,4],
-"md_docs_2Quickstart.html#entity":[2,1,1],
-"md_docs_2Quickstart.html#hierarchies":[2,1,6],
-"md_docs_2Quickstart.html#id":[2,1,2],
-"md_docs_2Quickstart.html#module":[2,1,13],
-"md_docs_2Quickstart.html#observer":[2,1,12],
-"md_docs_2Quickstart.html#pair":[2,1,5],
-"md_docs_2Quickstart.html#pipeline":[2,1,11],
-"md_docs_2Quickstart.html#query":[2,1,9],
-"md_docs_2Quickstart.html#running-tests-bake":[2,0,3]
+"md_docs_2Queries.html#operator-overview":[5,6,4]
 };
