@@ -69,11 +69,11 @@ var searchData=
   ['do_20i_20detect_20which_20entities_20have_20changed_66',['How do I detect which entities have changed?',['../md_docs_2FAQ.html#how-do-i-detect-which-entities-have-changed',1,'']]],
   ['doc_67',['Doc',['../group__cpp__addons__doc.html',1,'Doc'],['../group__c__addons__doc.html',1,'Doc']]],
   ['doc_2eh_68',['doc.h',['../doc_8h.html',1,'']]],
-  ['doc_5fbrief_69',['doc_brief',['../group__cpp__addons__doc.html#gabf672e81afeddec4a4e2c0f8250ff021',1,'flecs::entity_view']]],
-  ['doc_5fcolor_70',['doc_color',['../group__cpp__addons__doc.html#gac9ee07df2042efd85259a7cf2c4e55f6',1,'flecs::entity_view']]],
-  ['doc_5fdetail_71',['doc_detail',['../group__cpp__addons__doc.html#gaad57d5f8523631450f0e3ea083fb0d35',1,'flecs::entity_view']]],
-  ['doc_5flink_72',['doc_link',['../group__cpp__addons__doc.html#gaa537a0f49dbd7c563900f2480f85d6a0',1,'flecs::entity_view']]],
-  ['doc_5fname_73',['doc_name',['../structecs__alert__desc__t.html#aa9bbb8c2495dc6b281378d4403d95ef7',1,'ecs_alert_desc_t::doc_name'],['../structflecs_1_1alert__builder__i.html#a3e72987051e58d7bc94f98b7ce95c5ce',1,'flecs::alert_builder_i::doc_name()'],['../group__cpp__addons__doc.html#ga53dd532bce312cc69414e44c4cb9f938',1,'flecs::entity_view::doc_name()']]],
+  ['doc_5fbrief_69',['doc_brief',['../group__cpp__addons__doc.html#gabf672e81afeddec4a4e2c0f8250ff021',1,'flecs::entity_view::doc_brief() const'],['../structflecs_1_1entity__view.html#gabf672e81afeddec4a4e2c0f8250ff021',1,'flecs::entity_view::doc_brief() const'],['../structflecs_1_1entity__view.html#gabf672e81afeddec4a4e2c0f8250ff021',1,'flecs::doc_brief()']]],
+  ['doc_5fcolor_70',['doc_color',['../group__cpp__addons__doc.html#gac9ee07df2042efd85259a7cf2c4e55f6',1,'flecs::entity_view::doc_color() const'],['../structflecs_1_1entity__view.html#gac9ee07df2042efd85259a7cf2c4e55f6',1,'flecs::entity_view::doc_color() const'],['../structflecs_1_1entity__view.html#gac9ee07df2042efd85259a7cf2c4e55f6',1,'flecs::doc_color()']]],
+  ['doc_5fdetail_71',['doc_detail',['../group__cpp__addons__doc.html#gaad57d5f8523631450f0e3ea083fb0d35',1,'flecs::entity_view::doc_detail() const'],['../structflecs_1_1entity__view.html#gaad57d5f8523631450f0e3ea083fb0d35',1,'flecs::entity_view::doc_detail() const'],['../structflecs_1_1entity__view.html#gaad57d5f8523631450f0e3ea083fb0d35',1,'flecs::doc_detail()']]],
+  ['doc_5flink_72',['doc_link',['../group__cpp__addons__doc.html#gaa537a0f49dbd7c563900f2480f85d6a0',1,'flecs::entity_view::doc_link() const'],['../structflecs_1_1entity__view.html#gaa537a0f49dbd7c563900f2480f85d6a0',1,'flecs::entity_view::doc_link() const'],['../structflecs_1_1entity__view.html#gaa537a0f49dbd7c563900f2480f85d6a0',1,'flecs::doc_link()']]],
+  ['doc_5fname_73',['doc_name',['../structecs__alert__desc__t.html#aa9bbb8c2495dc6b281378d4403d95ef7',1,'ecs_alert_desc_t::doc_name'],['../group__cpp__addons__doc.html#ga53dd532bce312cc69414e44c4cb9f938',1,'flecs::entity_view::doc_name()'],['../structflecs_1_1alert__builder__i.html#a3e72987051e58d7bc94f98b7ce95c5ce',1,'flecs::alert_builder_i::doc_name()'],['../structflecs_1_1entity__view.html#ga53dd532bce312cc69414e44c4cb9f938',1,'flecs::entity_view::doc_name()'],['../structflecs_1_1entity__view.html#ga53dd532bce312cc69414e44c4cb9f938',1,'flecs::doc_name()']]],
   ['documentation_74',['Documentation',['../md_docs_2Docs.html',1,'']]],
   ['does_20a_20locked_5fstorage_20error_20mean_75',['What does a LOCKED_STORAGE error mean?',['../md_docs_2FAQ.html#what-does-a-locked_storage-error-mean',1,'']]],
   ['does_20flecs_20compare_20with_20entt_76',['How does Flecs compare with EnTT?',['../md_docs_2FAQ.html#how-does-flecs-compare-with-entt',1,'']]],
